@@ -3,8 +3,7 @@
 import typer
 
 filename_option = typer.Argument(
-    "/media/leynier/SSD/Projects/viera-academy-app"
-    + "/ProjectSettings/ProjectSettings.asset",
+    "/home/leynier/projects/viera-academy-app/ProjectSettings/ProjectSettings.asset",
     # join(".", "ProjectSettings", "ProjectSettings.asset"),
     exists=True,
     file_okay=True,
